FormatOutput

Struct FormatOutput 

pub struct FormatOutput {
    pub prefix_ws_len: Option<usize>,
    pub len: usize,
    pub is_empty: bool,
    pub is_blank: bool,
    pub multiline: Option<FormatMultilineOutput>,
}
Formatting output

Fields

prefix_ws_len: Option<usize>

Prefix whitespace length, if any

len: usize

Total length of this type

is_empty: bool

Whether the type was empty

is_blank: bool

Whether the type was blank

multiline: Option<FormatMultilineOutput>

Multi-line output

Implementations

Source

impl FormatOutput

pub const fn has_prefix_ws(&self) -> bool

Returns if this format output has any prefix whitespace

pub fn len_without_prefix_ws(&self) -> usize

Returns the length of this type, excluding the prefix whitespace, if any

pub fn len_non_multiline_ws(&self) -> usize

Returns the non-whitespace non-multiline whitespace length of this type

pub const fn join(lhs: Self, rhs: Self) -> Self

Joins two format outputs.

You must ensure that rhs directly follows lhs.

pub const fn append(&mut self, other: Self)

Appends a format output to this one.

See join for details.

pub const fn append_to(self, output: &mut Self)

Appends this format output to output.

See join for details.