Context

Struct Context 

pub struct Context<'a> { /* private fields */ }
Format context

Implementations

Source

impl<'a> Context<'a>

pub fn new(input: impl Into<ArcStr>, config: &'a Config) -> Self

Creates a new context

pub fn format<T, PrefixWs>( &mut self, value: &mut T, prefix_ws: PrefixWs, ) -> FormatOutput
where T: Format<PrefixWs, ()>,

Formats a value

pub fn format_with<T, PrefixWs, A>( &mut self, value: &mut T, prefix_ws: PrefixWs, args: A, ) -> FormatOutput
where T: Format<PrefixWs, A>,

Formats a value with arguments

pub const fn input(&self) -> &ArcStr

Returns the input

pub fn config(&self) -> &Config

Returns the config

pub fn config_mut(&mut self) -> &mut Config

Returns the config mutably

pub const fn indent(&self) -> usize

Returns the indentation level

pub fn with_indent<O>(&mut self, f: impl FnOnce(&mut Self) -> O) -> O

Runs f with a further indentation level

pub fn with_indent_if<O>( &mut self, pred: bool, f: impl FnOnce(&mut Self) -> O, ) -> O

Runs f with a further indentation level if pred is true

pub fn without_indent<O>( &mut self, f: impl for<'b> FnOnce(&'b mut Self) -> O, ) -> O

Runs f with one less indentation level

pub fn without_indent_if<O>( &mut self, pred: bool, f: impl for<'b> FnOnce(&'b mut Self) -> O, ) -> O

Runs f with one less indentation level if pred is true, otherwise runs it with the current indent

pub fn with_indent_offset<O>( &mut self, offset: i16, f: impl for<'b> FnOnce(&'b mut Self) -> O, ) -> O

Runs f with an indentation offset of offset

pub fn with_indent_offset_if<O>( &mut self, offset: i16, pred: bool, f: impl for<'b> FnOnce(&'b mut Self) -> O, ) -> O

Runs f with an indentation offset of offset if pred is true

pub fn sub_context(&mut self) -> Context<'_>

Creates a sub-context.

Sub contexts have their own configuration

pub fn add_tag(&mut self, tag: FormatTag) -> bool

Adds a tag.

Returns if the tag was present

pub fn remove_tag(&mut self, tag: FormatTag) -> bool

Removes a tag.

Returns if the tag was present

pub fn set_tag(&mut self, tag: FormatTag, present: bool) -> bool

Sets whether a tag is present.

Returns if the tag was present

pub fn has_tag(&self, tag: FormatTag) -> bool

Returns if a tag exists

pub fn with_tag<O>( &mut self, tag: FormatTag, f: impl FnOnce(&mut Self) -> O, ) -> O

Runs f with a tag, removing it after

pub fn with_tag_if<O>( &mut self, pred: bool, tag: FormatTag, f: impl FnOnce(&mut Self) -> O, ) -> O

Runs f with a tag if pred is true, removing it after

pub fn without_tag<O>( &mut self, tag: FormatTag, f: impl FnOnce(&mut Self) -> O, ) -> O

Runs f without a tag, adding it after if it existed

pub fn without_tag_if<O>( &mut self, pred: bool, tag: FormatTag, f: impl FnOnce(&mut Self) -> O, ) -> O

Runs f without a tag if pred is true, adding it after if it existed