pub struct FormatOutput {
pub prefix_ws_len: Option<usize>,
pub len: usize,
pub is_empty: bool,
pub is_blank: bool,
pub multiline: Option<FormatMultilineOutput>,
}Expand description
Formatting output
Fields
prefix_ws_len: Option<usize>Prefix whitespace length, if any
len: usizeTotal length of this type
is_empty: boolWhether the type was empty
is_blank: boolWhether the type was blank
multiline: Option<FormatMultilineOutput>Multi-line output
Implementations
Sourceimpl FormatOutput
impl FormatOutput
Sourcepub const fn has_prefix_ws(&self) -> bool
pub const fn has_prefix_ws(&self) -> bool
Returns if this format output has any prefix whitespace
Sourcepub fn len_without_prefix_ws(&self) -> usize
pub fn len_without_prefix_ws(&self) -> usize
Returns the length of this type, excluding the prefix whitespace, if any
Sourcepub fn len_non_multiline_ws(&self) -> usize
pub fn len_non_multiline_ws(&self) -> usize
Returns the non-whitespace non-multiline whitespace length of this type
Sourcepub const fn join(lhs: Self, rhs: Self) -> Self
pub const fn join(lhs: Self, rhs: Self) -> Self
Joins two format outputs.
You must ensure that rhs directly follows lhs.